
## CATO-CLI - mutation.sites.removeStaticHost:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeStaticHost) for documentation on this operation.

### Usage for mutation.sites.removeStaticHost:

`catocli mutation sites removeStaticHost -h`

`catocli mutation sites removeStaticHost <json>`

`catocli mutation sites removeStaticHost "$(cat < mutation.sites.removeStaticHost.json)"`

`catocli mutation sites removeStaticHost '{"hostId":"id"}'`

`catocli mutation sites removeStaticHost -p '{
    "hostId": "id"
}'`


#### Operation Arguments for mutation.sites.removeStaticHost ####

`accountId` [ID] - (required) N/A    
`hostId` [ID] - (required) N/A    
